EmbyPy MISC
=====================

.. automodule:: embypy.objects
   :show-inheritance:

.. autosummary::
   Audio.album
   Audio.track_number
   Audio.album_artists
   Audio.artists
   Audio.album_primary_image_tag
   Audio.album_primary_image_url

   Person.role

   Image

   Game

   Book

.. autoclass:: Audio
   :members:

.. autoclass:: Person
   :members:

.. autoclass:: Image
   :members:

.. autoclass:: Game
   :members:

.. autoclass:: Book
   :members:
